@@ -154,46 +154,39 @@ static gint GdmFlexibleXservers = 5;
 static gint GdmFirstVt = 7;
 static gint GdmXserverTimeout = 10;
 
-/* The SDTLOGIN feature is Solaris specific, and causes the Xserver to be
- * run with user permissionsinstead of as root, which adds security but
- * disables the AlwaysRestartServer option as highlighted in the gdm
- * documentation */
-#ifdef sun
-gboolean GdmAlwaysRestartServer = TRUE;
-#else
-gboolean GdmAlwaysRestartServer = FALSE;
-#endif
-static gboolean GdmAutomaticLoginEnable = FALSE;
-static gboolean GdmConfigAvailable = FALSE;
-static gboolean GdmSystemMenu = FALSE;
-static gboolean GdmChooserButton = FALSE;
-static gboolean GdmBrowser = FALSE;
-static gboolean GdmAddGtkModules = FALSE;
-static gboolean GdmDoubleLoginWarning = TRUE;
-static gboolean GdmAlwaysLoginCurrentSession = FALSE;
-static gboolean GdmDisplayLastLogin = TRUE;
+gboolean GdmAlwaysRestartServer;
+static gboolean GdmAutomaticLoginEnable;
+static gboolean GdmConfigAvailable;
+static gboolean GdmSystemMenu;
+static gboolean GdmChooserButton;
+static gboolean GdmBrowser;
+static gboolean GdmAddGtkModules;
+static gboolean GdmDoubleLoginWarning;
+static gboolean GdmAlwaysLoginCurrentSession;
+static gboolean GdmDisplayLastLogin;
 static gboolean GdmMulticast;
-static gboolean GdmNeverPlaceCookiesOnNfs = TRUE;
-static gboolean GdmPasswordRequired = FALSE;
-static gboolean GdmKillInitClients = FALSE;
-static gboolean GdmXdmcp = FALSE;
-static gboolean GdmIndirect = FALSE;
-static gboolean GdmXdmcpProxy = FALSE;
-static gboolean GdmDebug = FALSE;
-static gboolean GdmDebugGestures = FALSE;
-static gboolean GdmAllowRoot = FALSE;
-static gboolean GdmAllowRemoteRoot = FALSE;
-static gboolean GdmAllowRemoteAutoLogin = FALSE;
-static gboolean GdmCheckDirOwner = TRUE;
-static gboolean GdmSupportAutomount = FALSE;
-static gboolean GdmTimedLoginEnable = FALSE;
-static gboolean GdmDynamicXservers = FALSE;
-static gboolean GdmVTAllocation = TRUE;
-static gboolean GdmDisallowTcp = TRUE;
-static gboolean GdmSoundOnLogin = TRUE;
-static gboolean GdmSoundOnLoginSuccess = FALSE;
-static gboolean GdmSoundOnLoginFailure = FALSE;
-static gboolean GdmConsoleNotify = TRUE;
+static gboolean GdmNeverPlaceCookiesOnNfs;
+static gboolean GdmPasswordRequired;
+static gboolean GdmKillInitClients;
+static gboolean GdmXdmcp;
+static gboolean GdmIndirect;
+static gboolean GdmXdmcpProxy;
+static gboolean GdmDebug;
+static gboolean GdmDebugGestures;
+static gboolean GdmAllowRoot;
+static gboolean GdmAllowRemoteRoot;
+static gboolean GdmAllowRemoteAutoLogin;
+static gboolean GdmCheckDirOwner;
+static gboolean GdmSupportAutomount;
+static gboolean GdmTimedLoginEnable;
+static gboolean GdmDynamicXservers;
+static gboolean GdmVTAllocation;
+static gboolean GdmDisallowTcp;
+static gboolean GdmSoundOnLogin;
+static gboolean GdmSoundOnLoginSuccess;
+static gboolean GdmSoundOnLoginFailure;
+static gboolean GdmConsoleNotify;
+static gboolean GdmXnestUnscaledFontPath;
 
 /* Config options used by slave */
 /* ---------------------------- */
@@ -424,6 +417,8 @@ gdm_config_init (void)
    gdm_config_add_hash (GDM_KEY_SOUND_ON_LOGIN, &GdmSoundOnLogin, &bool_type);
    gdm_config_add_hash (GDM_KEY_RESTART_BACKGROUND_PROGRAM,
       &GdmRestartBackgroundProgram, &bool_type);
+   gdm_config_add_hash (GDM_KEY_XNEST_UNSCALED_FONT_PATH,
+      &GdmXnestUnscaledFontPath, &bool_type);
 
    /* string values */
    gdm_config_add_hash (GDM_KEY_PATH, &GdmPath, &string_type);
@@ -655,7 +650,7 @@ gdm_get_custom_config (struct stat *statbuf)
  * appended, and never gdm.conf.
  */
 static gchar *
-gdm_get_per_display_custom_config_file (gchar *display)
+gdm_get_per_display_custom_config_file (const gchar *display)
 {
   return g_strdup_printf ("%s%s", custom_config_file, display);
 }
@@ -818,7 +813,7 @@ gboolean gdm_get_value_bool_per_display (gchar *display, gchar *key)
  * value if none exists.  Note that this value needs to be freed,
  * unlike the non-per-display version.
  */
-gchar * gdm_get_value_string_per_display (gchar *display, gchar *key)
+gchar * gdm_get_value_string_per_display (const gchar *display, gchar *key)
 {
    gchar *perdispval;
 
@@ -844,7 +839,7 @@ gchar * gdm_get_value_string_per_display (gchar *display, gchar *key)
  * sure they are added to the if-test below.
  */
 void
-gdm_config_key_to_string_per_display (gchar *display, gchar *key, gchar **retval)
+gdm_config_key_to_string_per_display (const gchar *display, gchar *key, gchar **retval)
 {
    gchar *file;
    gchar **splitstr = g_strsplit (key, "/", 2);
@@ -855,9 +850,10 @@ gdm_config_key_to_string_per_display (gchar *display, gchar *key, gchar **retval
 
    file = gdm_get_per_display_custom_config_file (display);
 
-   if (strcmp (ve_sure_string (splitstr[0]), "greeter") == 0 ||
-       strcmp (ve_sure_string (splitstr[0]), "gui") == 0 ||
-       is_key (key, GDM_KEY_PAM_STACK)) {
+   if (splitstr != NULL &&
+       (strcmp (ve_sure_string (splitstr[0]), "greeter") == 0 ||
+        strcmp (ve_sure_string (splitstr[0]), "gui") == 0 ||
+        is_key (key, GDM_KEY_PAM_STACK))) {
       gdm_config_key_to_string (file, key, retval);
    }
 
@@ -883,7 +879,7 @@ gdm_config_key_to_string (gchar *file, gchar *key, gchar **retval)
    *retval = NULL;
 
    /* Should not fail, all keys should have a category. */
-   if (splitstr[0] == NULL)
+   if (splitstr == NULL || splitstr[0] == NULL)
       return;
 
    /* If file doesn't exist, then just return */
@@ -1773,7 +1769,7 @@ gdm_update_config (gchar* key)
    if (custom_cfg != NULL) {
        gchar **splitstr = g_strsplit (key, "/", 2);
 
-       if (splitstr[0] != NULL) {
+       if (splitstr != NULL && splitstr[0] != NULL) {
           GList *list = ve_config_get_keys (custom_cfg, splitstr[0]);
 
           while (list != NULL) {
@@ -1961,7 +1957,7 @@ gdm_load_config_option (gpointer key_in, gpointer value_in, gpointer data)
       /* First check the custom file */
       if (cfgfiles->custom_cfg != NULL) {
           gchar **splitstr = g_strsplit (key_in, "/", 2);
-          if (splitstr[0] != NULL) {
+          if (splitstr != NULL && splitstr[0] != NULL) {
              GList *list = ve_config_get_keys (cfgfiles->custom_cfg, splitstr[0]);
 
              while (list != NULL) {
@@ -2013,10 +2009,15 @@ gdm_config_parse (void)
 
    /*
     * It is okay if the custom_cfg file is missing, then just use
-    * main configuration file.  If cfg is missing, then GDM will 
-    * use the built-in defaults found in gdm.h.
+    * main configuration file. However if main config file does 
+    * not exist we cannot continue and need to bail out.
     */
+
    cfg                      = gdm_get_default_config (&statbuf);
+
+   if (cfg == NULL)
+	   gdm_fail (_("%s: Main config file (defaults.conf) is missing. Aborting!"), "gdm_config_parse");
+
    config_file_mtime        = statbuf.st_mtime;
    custom_cfg               = gdm_get_custom_config (&statbuf);
    custom_config_file_mtime = statbuf.st_mtime;
