@@ -19,16 +19,16 @@
  * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  */
-#include <config.h>
+
+#include "config.h"
+
 #include <string.h>
 #include <unistd.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <locale.h>
 
-/* we don't actually use libgnome, that's just for includes */
-#include <libgnome/libgnome.h>
-
+#include "ve-i18n.h"
 #include "ve-misc.h"
 
 char *
@@ -53,9 +53,9 @@ ve_find_file (const char *filename, const GList *directories)
 	path = g_getenv ("GNOME_PATH");
 	if (path != NULL) {
 		pathv = g_strsplit (path, ":", 0);
-		for (i = 0; pathv[i] != NULL; i++) {
+		for (i = 0; pathv != NULL && pathv[i] != NULL; i++) {
 			s = g_build_filename (pathv[i], "share", filename, NULL);
-			if (access (s, F_OK) == 0) {
+			if (g_access (s, F_OK) == 0) {
 				g_strfreev (pathv);
 				return s;
 			}
@@ -63,7 +63,7 @@ ve_find_file (const char *filename, const GList *directories)
 			s = g_build_filename (pathv[i], "share",
 					      g_get_prgname (),
 					      filename, NULL);
-			if (access (s, F_OK) == 0) {
+			if (g_access (s, F_OK) == 0) {
 				g_strfreev (pathv);
 				return s;
 			}
@@ -132,7 +132,7 @@ unalias_lang (char *lang)
         {
           static gboolean said_before = FALSE;
 	  if (!said_before)
-            g_warning (_("Too many alias levels for a locale, "
+            g_warning (_("Too many alias levels for a locale; "
 			 "may indicate a loop"));
 	  said_before = TRUE;
 	  return lang;
@@ -222,10 +222,10 @@ compute_locale_variants (const gchar *locale)
 {
   GList *retval = NULL;
 
-  gchar *language;
-  gchar *territory;
-  gchar *codeset;
-  gchar *modifier;
+  gchar *language = NULL;
+  gchar *territory = NULL;
+  gchar *codeset = NULL;
+  gchar *modifier = NULL;
 
   guint mask;
   guint i;
